Index: /branches/eam_branches/ipp-20111122/Ohana/src/dvosplit/src/dvosplit.c
===================================================================
--- /branches/eam_branches/ipp-20111122/Ohana/src/dvosplit/src/dvosplit.c	(revision 33449)
+++ /branches/eam_branches/ipp-20111122/Ohana/src/dvosplit/src/dvosplit.c	(revision 33450)
@@ -31,5 +31,6 @@
   }
 
-  // XXX should strip off any trailing slashes
+  // dvosplit can be run locally (no -outdir specified); otherwise, copy Photcode.dat,
+  // Images.dat, SkyTable.fits
   int LocalCopy = !strcmp (CATDIR, OUTDIR);
 
@@ -127,5 +128,5 @@
   }
 
   // save sky table copy
   filename = SkyTableFilename (OUTDIR);
   check_file_access (filename, TRUE, TRUE, VERBOSE);
@@ -135,4 +136,11 @@
   }
 
+  if (!LocalCopy) {
+    // copy the images table
+    char line[2048];
+    snprintf (line, 2048, "cp %s/Images.dat %s/Images.dat", CATDIR, OUTDIR);
+    system (line);
+  }
+
   exit (0);
 }
@@ -127,5 +128,5 @@
   }
 
-  // save sky table copy
+  // save sky table copy (Local or not Local : the depth has changed)
   filename = SkyTableFilename (OUTDIR);
   check_file_access (filename, TRUE, TRUE, VERBOSE);
